@@ -1,6 +1,6 @@
   /*
 
-  knetfilter v 2.0.1
+  knetfilter v 2.0.3
 
   Copyright (C) 2000 Luigi Genoni
   		     venom@DarkStar.sns.it
@@ -86,27 +86,91 @@ void knetfilter::startmangleEntries() {
 
 };
 
+void knetfilter::startNMap() {
+
+  QString mapaddr, mapnetmask, mapnet;
+
+  nmap.clearArguments();
+
+  mapaddr.sprintf((const char*)(mapNet->text()));  
+  mapnetmask.sprintf((const char*)(mapNetMask->text()));  
+  mapnet.sprintf("%s/%s",(const char*)(mapNet->text()), (const char*)(mapNetMask->text()));  
+
+  if ((strcmp((const char*)(mapNetMask->text()),"255.0.0.0")==0)) 
+    {
+      mapnetmask.sprintf("8");
+      mapnet.sprintf("%s/%s",(const char*)(mapNet->text()), ("8"));
+    }
+
+  if ((strcmp((const char*)(mapNetMask->text()),"255.255.0.0")==0)) 
+    {
+      mapnetmask.sprintf("16");
+      mapnet.sprintf("%s/%s",(const char*)(mapNet->text()), ("16"));
+    }
+
+  if ((strcmp((const char*)(mapNetMask->text()),"255.255.255.0")==0)) 
+    {
+      mapnetmask.sprintf("24");
+      mapnet.sprintf("%s/%s",(const char*)(mapNet->text()), ("24"));
+    }
+
+  if ((strcmp((const char*)(mapNetMask->text()),"255.255.255.255")==0)) 
+    {
+      mapnetmask.sprintf("32");
+      mapnet.sprintf("%s/%s",(const char*)(mapNet->text()), ("32"));
+    }
+
+  if (mapaddr.length()==0)
+    {
+      QMessageBox::critical(0, "Error",
+			    "You have to supply a network address\n");
+    }
+
+  if ((strcmp((const char*)(mapNetMask->text()),"0.0.0.0")==0)) 
+    {
+      QMessageBox::critical(0, "Error",
+			    "A NetMask like 0.0.0.0 is not allowed\n");
+    }
+  if ((strcmp((const char*)(mapNetMask->text()),"0")==0)) 
+    {
+      QMessageBox::critical(0, "Error",
+			    "A NetMask like 0.0.0.0 is not allowed\n");
+    }
+
+  nmap << "nmap"  << "-O" << "-v"  << nmapopt << nmapopt_icmp << mapnet;
+
+
+  bool success=nmap.start(KProcess::NotifyOnExit,
+			  KProcess::AllOutput);
+
+  if (success)
+    statusbar->message(i18n("Running..."), 2000);
+  else
+    statusbar->message(i18n("Couldn't start nmap"), 2000);
+
+};
+  
 
 
 void knetfilter::starttcpDump() {
 
-      tcpdump.clearArguments();
-   char interfaceChoice2[5]; 
-   strcpy( interfaceChoice2, interfaceChoice );	
-    
-    interfaceChoicedmp = strcat ( interfaceChoice2, interfacenrChoicedmp);
-    
-    //tcpdump << "tcpdump" <<"-c 1000" << "-i" << "eth0" ; 
-    tcpdump << "tcpdump" <<"-c 1000" << "-i" << interfaceChoicedmp ; 
-
-
-    bool success=tcpdump.start(KProcess::NotifyOnExit,
-			       KProcess::AllOutput);
-            if (success)
-          statusbar->message(i18n("Running..."), 2000);
-       else
-          statusbar->message(i18n("Couldn't start tcpdump"), 2000);
-
+  tcpdump.clearArguments();
+  char interfaceChoice2[5]; 
+  strcpy( interfaceChoice2, interfaceChoice );	
+  
+  interfaceChoicedmp = strcat ( interfaceChoice2, interfacenrChoicedmp );
+  
+  //tcpdump << "tcpdump" <<"-c 1000" << "-i" << "eth0" ; 
+  tcpdump << "tcpdump" <<"-c 1000" << "-i" << interfaceChoicedmp ; 
+  
+  
+  bool success=tcpdump.start(KProcess::NotifyOnExit,
+			     KProcess::AllOutput);
+  if (success)
+    statusbar->message(i18n("Running..."), 2000);
+  else
+    statusbar->message(i18n("Couldn't start tcpdump"), 2000);
+  
 };
 
 
@@ -246,6 +310,144 @@ void knetfilter::iptablesRules() {
     }  
 };
 
+
+void knetfilter::tcpDump() {
+  if ( dumpList == NULL )
+    { 
+
+      dumpList = new KNFWidget();
+      dumpList->resize(550,420);
+      dumpList->setCaption("tcpdump");
+      
+      QBoxLayout *top = new QBoxLayout(dumpList, QBoxLayout::LeftToRight, 5);
+      QGridLayout *grid = new QGridLayout(5,5);
+      top->addLayout(grid,5);
+  
+      dumpBox = new QListBox(dumpList);
+      grid->addMultiCellWidget(dumpBox,0,3,0,4);
+  
+      QPushButton *btnDump = new QPushButton(dumpList);
+      btnDump->setText("tcpdump");
+      btnDump->setFixedHeight(btnDump->sizeHint().height());
+      connect(btnDump,SIGNAL(clicked()), this, SLOT(starttcpDump()));
+      grid->addWidget(btnDump,4,1);
+        
+      QPushButton *btnClose = new QPushButton(dumpList);
+      btnClose->setText("Close");
+      btnClose->setFixedHeight(btnClose->sizeHint().height());
+      connect(btnClose,SIGNAL(clicked()), this, SLOT(closetcpDump()));
+      grid->addWidget(btnClose,4,3);
+  
+      dumpList->show();
+      setView(dumpList);
+    }
+  else
+    {
+      if ( !dumpList->isVisible() )
+	{
+	  dumpList->show();
+	}
+      else
+    	{
+	  QMessageBox::critical(0,"Warning", "Already Running\n");      
+	}
+    }  
+};
+
+
+void knetfilter::NMap(){
+  
+  if ( mapList == NULL )
+  {
+     
+      mapList = new KNFWidget();
+      mapList->resize(640,480);
+      mapList->setCaption("nmap");
+
+      QBoxLayout *top = new QBoxLayout(mapList, QBoxLayout::LeftToRight, 7);
+      QGridLayout *grid = new QGridLayout(8,7);
+      top->addLayout(grid,7);  
+
+      mapBox = new QListBox(mapList);
+      grid->addMultiCellWidget(mapBox,0,5,0,7);
+
+      
+      QLabel *labelmapNet = new QLabel(mapList);
+      labelmapNet->setText("address/metmask:");
+
+      grid->addMultiCellWidget(labelmapNet,6,6,0,1);
+
+      mapNet= new QLineEdit(mapList);
+      mapNetMask= new QLineEdit(mapList);
+      
+      mapNet->setFixedHeight(mapNet->sizeHint().height());
+      mapNet->setFixedHeight(mapNetMask->sizeHint().height());
+
+      
+      grid->addMultiCellWidget(mapNet,6,6,2,2);
+      grid->addMultiCellWidget(mapNetMask,6,6,4,5);
+
+      QLabel *labelnmapoptions = new QLabel(mapList);
+      labelnmapoptions->setText("NMap Options:");
+      grid->addMultiCellWidget(labelnmapoptions,7,7,0,1);
+
+      nmapoptions = new QComboBox ( FALSE, mapList, "nmapoptions");
+      nmapoptions->insertItem("TCP connect scan (-sT)");
+      nmapoptions->insertItem("TCP connect+Ident scan (-I very slow)");
+      nmapoptions->insertItem("TCP SYN scan (-sS)");
+      nmapoptions->insertItem("TCP Stealth FIN scan (-sF)");
+      nmapoptions->insertItem("TCP Xmas Tree scan (-sX)");
+      nmapoptions->insertItem("TCP NULL scan (-sN)");
+      nmapoptions->insertItem("TCP ACK scan (-sA)");
+      nmapoptions->insertItem("TCP Window scan (-sW)");
+      nmapoptions->insertItem("TCP RPC scan (-sR)");
+      nmapoptions->insertItem("UDP scan (-sU very slow)");
+      nmapoptions->insertItem("PING scan (-sP)");
+      connect(nmapoptions,SIGNAL(activated(int)), SLOT(nmapoptActivated(int)));
+      grid->addMultiCellWidget(nmapoptions,7,7,2,2);
+
+      QLabel *labelnmapoptions_icmp = new QLabel(mapList);
+      labelnmapoptions_icmp->setText("NMap Options:");
+      grid->addMultiCellWidget(labelnmapoptions_icmp,7,7,3,4);
+
+      nmapoptions_icmp = new QComboBox ( FALSE, mapList, "nmapoptions_icmp");
+      nmapoptions_icmp->insertItem("Standard ping (-PB = -PI -PT");
+      nmapoptions_icmp->insertItem("ICMP ping (-PI)");
+      nmapoptions_icmp->insertItem("TCP ping (-PT)");
+      nmapoptions_icmp->insertItem("TCP SYN ping (-PS)");
+      nmapoptions_icmp->insertItem("Don't ping (-P0)");
+      connect(nmapoptions_icmp,SIGNAL(activated(int)), SLOT(nmapoptActivated_icmp(int)));
+      grid->addMultiCellWidget(nmapoptions_icmp,7,7,5,5);
+
+      QPushButton *btnMap = new QPushButton(mapList);
+      btnMap->setText("nmap");
+      btnMap->setFixedHeight(btnMap->sizeHint().height());
+      connect(btnMap,SIGNAL(clicked()), this, SLOT(startNMap()));
+      grid->addWidget(btnMap,8,1);
+
+      QPushButton *btnClose = new QPushButton(mapList);
+      btnClose->setText("Close");
+      btnClose->setFixedHeight(btnClose->sizeHint().height());
+      connect(btnClose,SIGNAL(clicked()), this, SLOT(closeNMap()));
+      grid->addWidget(btnClose,8,3);       
+      
+      mapList->show();
+      setView(mapList); 
+      
+  }
+  else
+     {
+      if (!mapList->isVisible() )
+	{
+	  mapList->show();
+	}
+      else
+	{
+          QMessageBox::critical(0,"Warning", "Already Running\n");
+        }
+    }
+};   
+	  
 void knetfilter::closepolRules() {
 
   polList->close();
@@ -264,6 +466,12 @@ void knetfilter::closetcpDump() {
 
 };
 
+void knetfilter::closeNMap() {
+
+  mapList->close();
+
+};
+
 void knetfilter::polRulesDone() {
   if (polrules.normalExit() && (polrules.exitStatus()==0))
     statusbar->message(i18n("Setting Chain Policy..."), 2000);
@@ -352,49 +560,6 @@ void knetfilter::listRules(KProcess *, char *data, int len) {
   };
 };
 
-void knetfilter::tcpDump() {
-  if ( dumpList == NULL )
-    { 
-
-      dumpList = new KNFWidget();
-      dumpList->resize(550,420);
-      dumpList->setCaption("tcpdump");
-      
-      QBoxLayout *top = new QBoxLayout(dumpList, QBoxLayout::LeftToRight, 5);
-      QGridLayout *grid = new QGridLayout(5,5);
-      top->addLayout(grid,5);
-  
-      dumpBox = new QListBox(dumpList);
-      grid->addMultiCellWidget(dumpBox,0,3,0,4);
-  
-      QPushButton *btnDump = new QPushButton(dumpList);
-      btnDump->setText("tcpdump");
-      btnDump->setFixedHeight(btnDump->sizeHint().height());
-      connect(btnDump,SIGNAL(clicked()), this, SLOT(starttcpDump()));
-      grid->addWidget(btnDump,4,0);
-        
-      QPushButton *btnClose = new QPushButton(dumpList);
-      btnClose->setText("Close");
-      btnClose->setFixedHeight(btnClose->sizeHint().height());
-      connect(btnClose,SIGNAL(clicked()), this, SLOT(closetcpDump()));
-      grid->addWidget(btnClose,4,2);
-  
-      dumpList->show();
-      setView(dumpList);
-    }
-  else
-    {
-      if ( !dumpList->isVisible() )
-	{
-	  dumpList->show();
-	}
-      else
-    	{
-	  QMessageBox::critical(0,"Warning", "Already Running\n");      
-	}
-    }  
-};
-
 
 void knetfilter::listDump(KProcess *, char *data, int len) {
 
@@ -432,7 +597,41 @@ void knetfilter::listDump(KProcess *, char *data, int len) {
 
 };
 
+void knetfilter::portDump(KProcess *, char *data, int len) {
 
+  if (len<0)
+    return;
+  static QString remainder;
+  QString list;
+  char dst[len+1];
+  memmove(dst,data,len);
+  dst[len]=0;
+
+  list=remainder+dst;
+  QStrList lines;
+  int index=0;
+  int newindex=0;
+
+  while (1)
+  {
+    newindex=list.find('\n',index);
+    if(newindex==-1) {
+      remainder=list.right(list.length()-index);
+      break;
+    } else {
+      lines.append(list.mid(index,newindex-index));
+      index=newindex+1;
+    };
+  };
+
+  if(lines.count()>0) 
+    mapBox->insertStrList(&lines);
+
+ mapBox->insertItem(remainder.data());
+ mapBox->setTopItem(mapBox->count()-mapBox->numItemsVisible());
+
+};
+  
 // probe interface action
 void knetfilter::startprobeInterface() {
 
@@ -790,6 +989,69 @@ void knetfilter::chainpolicyActivated(int index) {
 };
 
 
+void knetfilter::nmapoptActivated(int index) {
+  switch(index) {
+  default:
+    nmapopt = "-sT";
+  case 0:
+    nmapopt = "-sT";
+  break; 
+  case 1:
+    nmapopt = "-I";
+  break; 
+  case 2:
+    nmapopt = "-sS";
+  break; 
+  case 3:
+    nmapopt = "-sF";
+  break; 
+  case 4:
+    nmapopt = "-sX";
+  break; 
+  case 5:
+    nmapopt = "-sN";
+  break; 
+  case 6:
+    nmapopt = "-sA";
+  break; 
+  case 7:
+    nmapopt = "-sW";
+  break; 
+  case 8:
+    nmapopt = "-sR";
+  break; 
+  case 9:
+    nmapopt = "-sU";
+  break; 
+  case 10:
+    nmapopt = "-sP";
+  break; 
+  };
+};
+
+
+void knetfilter::nmapoptActivated_icmp(int index) {
+  switch(index) {
+  default:
+    nmapopt_icmp = "-PB";
+  case 0:
+    nmapopt_icmp = "-PB";
+  break;
+  case 1:
+    nmapopt_icmp = "-PI";
+  break;
+  case 2:
+    nmapopt_icmp = "-PT";
+  break;
+  case 3:
+    nmapopt_icmp = "-PS";
+  break;
+  case 4:
+    nmapopt_icmp = "-P0";
+  break;
+  };
+};
+
 // I was forgeting ...
 void knetfilter::userEntries(KProcess *, char *data, int len) {
 
