@@ -1,6 +1,6 @@
   /*
 
-  knat v 1.1.2
+  knat v 2.0.3
 
   Copyright (C) 2000 Luigi Genoni
   		     venom@DarkStar.sns.it
@@ -20,6 +20,9 @@
 #include <klocale.h>
 #include <kmenubar.h>
 
+// This is for some "strange compilers" running with "strange" big mass distributions
+#include <stdlib.h>
+
 #include "knat.moc"
 
 #include "version.h"
@@ -52,6 +55,8 @@ knetfilter::knetfilter( QWidget *, const char *name )
     mangleactionChoice = "TOS";
     mangletosChoice = "0";
     mangleSyn = "-v";
+    nmapopt = "-sT";
+    nmapopt_icmp = "-PB";
     logLevel = "0";
     log1="-v";
     log2="-v";
@@ -80,6 +85,7 @@ knetfilter::knetfilter( QWidget *, const char *name )
 	mangleList = NULL;
 	manglepolList = NULL;
 	dumpList = NULL;
+	mapList = NULL;
 	masqWin = NULL;
 };
 
@@ -171,6 +177,8 @@ void knetfilter::setupMenuBar() {
   options->insertSeparator();
   options->insertItem(i18n("TcpDump"),
   				this, SLOT(tcpDump()));
+  options->insertItem(i18n("NMap"),
+  				this, SLOT(NMap()));
   options->insertSeparator();
   options->insertItem(i18n("Probe interface"),
 	  			this, SLOT(startprobeInterface()));
